==> ja-xdtp-1.1.4.tbz: include/xdtp/modules/GLSDDocumentModule.h <==
/* 
 * $Id: GLSDDocumentModule.h,v 1.1 2005/10/11 07:35:02 ozawa Exp $
 *
 * Copyright 2005- ONGS Inc. All rights reserved.
 * 
 * author: Masanori OZAWA (ozawa@ongs.co.jp)
 * version: $Revision: 1.1 $
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 *   1. Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in the
 *      documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY ONGS INC ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ONGS INC OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 * The views and conclusions contained in the software and documentation are
 * those of the authors and should not be interpreted as representing official
 * policies, either expressed or implied, of the ONGS Inc.
 * 
 */

#ifndef ___GLSDDOCUMENTMODULE_H
#define ___GLSDDOCUMENTMODULE_H

#include "modules/XDTPModule.h"
#include "modules/imports/GLSDImportModule.h"

#include "libxml/tree.h"

namespace XDTP {

typedef std::list<GLSDImportModule*>    GLSDImportModuleList;

class GLSDDocumentModule : public XDTPModule
{
public:
	GLSDDocumentModule();
	virtual ~GLSDDocumentModule();

    /**
     * 򳫻Ϥ˽Ϸꤷޤ
     * 
     * @param aType Ϸ
     */
    virtual void setOutputType(const Glib::ustring& aType);
    
    /**
     * 򳫻Ϥ˥ץꤷޤ
     * 
     * @param anOptions ץ
     */
    virtual void setOption(const StringList& anOptions);

    /**
     * 򳫻Ϥ˽ϥե̾ꤷޤ
     * 
     * @param anOutputFile ϥե̾
     */
    virtual void setOutputFile(const Glib::ustring& anOutputFile);

    /**
     * 򳫻ϤѴXMLե̾ꤷޤ
     * 
     * @param aXMLFile ѴXMLե̾
     */
    virtual void setXMLFile(const Glib::ustring& aXMLFile);
    
    /**
     * ϥեΥ󥳡ɤꤷޤ
     * XMLեϤθ¤ǤϤޤ
     * 
     * @param anInputEncoding ϥեΥ󥳡
     */
    virtual void setInputEncoding(const Glib::ustring& anInputEncoding);

    /**
     * ϥեΥ󥳡ɤꤷޤ
     * 
     * @param anOutputEncoding ϥեΥ󥳡
     */
    virtual void setOutputEncoding(const Glib::ustring& anOutputEncoding);

    /**
     * եparseľ˸ƤӽФޤ
     * 
     * @param aFile parseоݤΥե̾
     */
    virtual void treatPreFile(const Glib::ustring& aFile);

    /**
     * parseXMLʸϤXSLѴľ˸ƤӽФޤ
     * 
     * @param aDocument XMLʸ
     */
    virtual void treatPreDocument(xmlDocPtr aDocument);

    /**
     * XSLѴXMLʸϤ¸ľ˸ƤӽФޤ
     * 
     * @param aDocument XMLʸ
     */
    virtual void treatPostDocument(xmlDocPtr aDocument);

    /**
     * XMLʸϤ¸ľ˸ƤӽФޤ
     * 
     * @param aFile ¸ե̾
     */
    virtual void treatPostFile(const Glib::ustring& aFile);
    
protected:
    /**
     * importɸಽޤ
     * ˰ʲνԤޤ<br>
     * <ul>
     *  <li>importפpޤ
     *  <li>importؤΥ󥫡ޤ
     * </ul>
     * 
     * @param aDocument
     *              ѴоDOMɥ
     */
    void normalizeImport(xmlDocPtr aDocument);

protected:
    GLSDImportModuleList m_ImportModules;
};

};

#endif

==> ja-xdtp-1.3.1_2.tbz: include/xdtp/modules/GLSDDocumentModule.h <==
/* 
 * $Id: GLSDDocumentModule.h,v 1.5 2006/06/29 07:26:42 ozawa Exp $
 *
 * Copyright 2005- ONGS Inc. All rights reserved.
 * 
 * author: Masanori OZAWA (ozawa@ongs.co.jp)
 * version: $Revision: 1.5 $
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 *   1. Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in the
 *      documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY ONGS INC ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ONGS INC OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 * The views and conclusions contained in the software and documentation are
 * those of the authors and should not be interpreted as representing official
 * policies, either expressed or implied, of the ONGS Inc.
 * 
 */

#ifndef ___GLSDDOCUMENTMODULE_H
#define ___GLSDDOCUMENTMODULE_H

#include "modules/XDTPModuleAdapter.h"
#include "modules/imports/GLSDImportModule.h"
#include "modules/imports/ImportTextGLSD.h"

#include "libxml/tree.h"

namespace XDTP {

typedef std::list<GLSDImportModule*>    GLSDImportModuleList;

class GLSDDocumentModule : public XDTPModuleAdapter
{
public:
	GLSDDocumentModule();
	virtual ~GLSDDocumentModule();

    /**
     * 򳫻Ϥ˽Ϸꤷޤ
     * 
     * @param aType Ϸ
     */
    virtual void setOutputType(const Glib::ustring& aType);
    
    /**
     * 򳫻Ϥ˥ץꤷޤ
     * 
     * @param anOptions ץ
     */
    virtual void setOption(const StringList& anOptions);

    /**
     * 򳫻Ϥ˽ϥե̾ꤷޤ
     * 
     * @param anOutputFile ϥե̾
     */
    virtual void setOutputFile(const Glib::ustring& anOutputFile);

    /**
     * 򳫻ϤѴXMLե̾ꤷޤ
     * 
     * @param aXMLFile ѴXMLե̾
     */
    virtual void setXMLFile(const Glib::ustring& aXMLFile);
    
    /**
     * ϥեΥ󥳡ɤꤷޤ
     * XMLեϤθ¤ǤϤޤ
     * 
     * @param anInputEncoding ϥեΥ󥳡
     */
    virtual void setInputEncoding(const Glib::ustring& anInputEncoding);

    /**
     * ϥեΥ󥳡ɤꤷޤ
     * 
     * @param anOutputEncoding ϥեΥ󥳡
     */
    virtual void setOutputEncoding(const Glib::ustring& anOutputEncoding);

    /**
     * ߤXDTPTransform⥸塼ꤷޤ
     * 
     * @param aXDTPTransform ߤXDTPTransform⥸塼
     */
    virtual void setXDTPTransform(const XDTPTransform *aXDTPTransform);

    /**
     * եparseľ˸ƤӽФޤ
     * 
     * @param aFile parseоݤΥե̾
     */
    virtual void treatPreFile(const Glib::ustring& aFile);

    /**
     * parseXMLʸϤXSLѴľ˸ƤӽФޤ
     * 
     * @param aDocument XMLʸ
     */
    virtual void treatPreDocument(xmlDocPtr aDocument);

    /**
     * XSLѴXMLʸϤ¸ľ˸ƤӽФޤ
     * 
     * @param aDocument XMLʸ
     */
    virtual void treatPostDocument(xmlDocPtr aDocument);

    /**
     * XMLʸϤ¸ľ˸ƤӽФޤ
     * 
     * @param aFile ¸ե̾
     */
    virtual void treatPostFile(const Glib::ustring& aFile);
    
protected:
    /**
     * importɸಽޤ
     * ˰ʲνԤޤ<br>
     * <ul>
     *  <li>importפpޤ
     *  <li>importؤΥ󥫡ޤ
     * </ul>
     * 
     * @param aDocument
     *              ѴоDOMɥ
     */
    void normalizeImport(xmlDocPtr aDocument);

    /**
     * alias ִޥåפۤޤ
     * 
     * @param aURL
     *              aliasִޥåץեؤURL
     * @param anOverWrite
     *              aliasִޥåפƱϿƤˡ
     *              ͤ񤭤 true ꤷޤ
     * @return ۤ true ꤷޤ
     */
    bool addAliasMap(const Glib::ustring& aURL, bool anOverWrite);

    /**
     * alias ִԤޤ
     * 
     * @param aDocument
     *              ѴоDOMɥ
     * @return ִ true ᤷޤ
     */
    bool replaceAllAlias(xmlDocPtr aDocument);

protected:
    GLSDImportModuleList    m_ImportModules;
    ImportTextGLSD          m_ImportTextGLSD;
    String2StringMap        m_AliasMap;
};

};

#endif
